# SPDX-License-Identifier: CECILL-2.1

module SpeechDatasets

using JSON
using SpeechFeatures
import MLUtils

export
    # ManifestItem
    Recording,
    Supervision,
    Alignment,
    load,

    # Manifest interface
    writemanifest,
    readmanifest,

    # Corpora interface
    download,
    lang,
    name,
    prepare,

    # Corpora
    MultilingualLibriSpeech,
    MINILIBRISPEECH,
    TIMIT,

    # Lexicon
    CMUDICT,
    TIMITDICT,

    # Dataset
    dataset

include("speechcorpus.jl")
include("manifest_item.jl")
include("manifest_io.jl")
include("dataset.jl")

# Supported corpora
include("corpora/multilingual_librispeech.jl")
include("corpora/mini_librispeech.jl")
include("corpora/timit.jl")

include("lexicons.jl")

end
